#!/usr/bin/env Rscript

#### Loading packages #### 
library(phyloseq) 
library(ape)
library(tidyverse)
library(vegan)
library(FSA)
library(ggsignif)

#### Loading data #### 
metafp <- "/Users/ashleenkhatra/Desktop/MICB_475/Project 2/Re-run2/re_metadata.tsv"
meta <- read_delim(metafp, delim="\t")

otufp <- "/Users/ashleenkhatra/Desktop/MICB_475/Project 2/Re-run2/feature-table.txt"
otu <- read_delim(file = otufp, delim="\t", skip=1)

taxfp <- "/Users/ashleenkhatra/Desktop/MICB_475/Project 2/Re-run2/taxonomy.tsv"
tax <- read_delim(taxfp, delim="\t")

phylotreefp <- "/Users/ashleenkhatra/Desktop/MICB_475/Project 2/Re-run2/tree.nwk"
phylotree <- read.tree(phylotreefp)

#### Formating the OTU table for phyloseq ####
# saving everything except first column (OTU ID) into a matrix
otu_mat <- as.matrix(otu[,-1])
# Making the first column (#OTU ID) the rownames of the new matrix
rownames(otu_mat) <- otu$'#OTU ID'
# Using the "otu_table" function to make an OTU table
OTU <- otu_table(otu_mat, taxa_are_rows = TRUE) 

#### Formating the sample metadata table for phyloseq ####
# Saving everything except sampleid as new data frame
samp_df <- as.data.frame(meta[,-1])
# Making the sampleids the rownames
rownames(samp_df)<- meta$"sample-id"
# Making phyloseq sample data with sample_data() function
SAMP <- sample_data(samp_df)

#### Formating the taxonomy table ####
# Converting the taxon strings to a table with separate taxa rank columns
tax_mat <- tax %>% select(-Confidence)%>%
  separate(col=Taxon, sep="; "
           , into = c("Domain","Phylum","Class","Order","Family","Genus","Species")) %>%
  as.matrix()
# Saving everything except feature IDs 
tax_mat <- tax_mat[,-1]
# Making the sampleids the rownames
rownames(tax_mat) <- tax$`Feature ID`
# Making a taxa table
TAX <- tax_table(tax_mat)

#### Create phyloseq object ####
# Merge all into a phyloseq object
dysautonomia <- phyloseq(OTU, SAMP, TAX, phylotree)

#### Looking at phyloseq object #####
# Viewing components of phyloseq object
otu_table(dysautonomia)
sample_data(dysautonomia)
tax_table(dysautonomia)
phy_tree(dysautonomia)

#### Filtering the data ####
# Removing chloroplasts, mitochondria, non-bacterial samples
dysautonomia_filt <- subset_taxa(dysautonomia,  Domain == "d__Bacteria" & Class!="c__Chloroplast" & Family !="f__Mitochondria")
# Removing the ASVs that have less than 5 counts total (low abundance ASVs)
dysautonomia_filt_nolow <- filter_taxa(dysautonomia_filt, function(x) sum(x)>5, prune = TRUE)
# Removing low quality samples with less than 100 reads
dysautonomia_filt_nolow_samps <- prune_samples(sample_sums(dysautonomia_filt_nolow)>100, dysautonomia_filt_nolow)
# Remove samples where FD.severity is na
dysautonomia_final <- subset_samples(dysautonomia_filt_nolow_samps, !is.na("FD.severity"))

#### Rarefy samples ####
rarecurve(t(as.data.frame(otu_table(dysautonomia_final))), cex=0.1)
dysautonomia_rare <- rarefy_even_depth(dysautonomia_final, rngseed = 1, sample.size = 9000)
# 54 out of 214 samples were removed
# 80 OTUs were removed

#### Saving the rarefy samples ####
save(dysautonomia_final, file="/Users/ashleenkhatra/Desktop/MICB_475/Project 2/Re-run2/dysautonomia_final.RData")
save(dysautonomia_rare, file="/Users/ashleenkhatra/Desktop/MICB_475/Project 2/Re-run2/dysautonomia_rare.RData")

#### Load in RData ####
load("/Users/ashleenkhatra/Desktop/MICB_475/Project 2/Re-run2/dysautonomia_final.RData")
load("/Users/ashleenkhatra/Desktop/MICB_475/Project 2/Re-run2/dysautonomia_rare.RData")

#### Alpha diversity metrics ####
# Shannon and Chao1 diversity plots
gg_richness <- plot_richness(dysautonomia_rare, x = "FD.severity", measures = c("Shannon","Chao1"), color = "FD.severity") +
  xlab("FD Severity Level") + stat_boxplot(geom = "errorbar", width = 0.15) +
  geom_boxplot()+ theme_bw()+
  scale_color_manual(values = c("#1A1A1A","#00b4d8","#0077b6","#03045e"))+
  theme(axis.text.x = element_text(angle = -90, size = 12),
        axis.title = element_text(face = "bold", size = 13),
        legend.text = element_text(size = 15),
        legend.title = element_text(size = 0.000000001))


gg_shannon <- plot_richness(dysautonomia_rare, x = "FD.severity", measures = c("Shannon"), color = "FD.severity") +
  xlab("FD Severity Level") + stat_boxplot(geom = "errorbar", width = 0.15) +
  geom_boxplot()+ theme_bw()+
  scale_color_manual(values = c("#1A1A1A","#00b4d8","#0077b6","#03045e"))+
  theme(axis.text.x = element_text(angle = -90, size = 12),
        axis.title = element_text(face = "bold", size = 13),
        legend.text = element_text(size = 15),
        legend.title = element_text(size = 0.000000001))

gg_chao1 <- plot_richness(dysautonomia_rare, x = "FD.severity", measures = c("Chao1"), color = "FD.severity") +
  xlab("FD Severity Level") + stat_boxplot(geom = "errorbar", width = 0.15) +
  geom_boxplot()+ theme_bw()+
  scale_color_manual(values = c("#1A1A1A","#00b4d8","#0077b6","#03045e"))+
  theme(axis.text.x = element_text(angle = -90, size = 12),
        axis.title = element_text(face = "bold", size = 13),
        legend.text = element_text(size = 15),
        legend.title = element_text(size = 0.000000001))

# Chao1 Figure with statistical significance (asterisks) 
gg_chao1_sf <- gg_chao1 + geom_signif(comparisons = list(c("control", "severe"),c("severe", "mild")),
                                      map_signif_level = TRUE, y_position = c(280, 320)) + ylim(50, 350)

# Statistical analysis for alpha diversity metrics
# Shannon diversity Kruskall-Wallis Test
alphadiv <- estimate_richness(dysautonomia_rare)
samp_dat <- sample_data(dysautonomia_rare)
samp_dat_wdiv <- data.frame(samp_dat, alphadiv)

kruskal.test(Shannon ~ FD.severity, data = samp_dat_wdiv)
# p-value = 0.9484

# Chao1 diversity Kruskall-Wallis Test
kruskal.test(Chao1 ~ FD.severity, data = samp_dat_wdiv)
# p-value = 0.001743


# Saving the alpha diversity bar plots
ggsave(filename = "/Users/ashleenkhatra/Desktop/MICB_475/Project 2/Re-run2/alpha_diversity_richness.png"
       , gg_richness
       , height=4, width=6)

ggsave(filename = "/Users/ashleenkhatra/Desktop/MICB_475/Project 2/Re-run2/shannon_diversity_richness.png"
       , gg_shannon
       , height=4, width=4)

ggsave(filename = "/Users/ashleenkhatra/Desktop/MICB_475/Project 2/Re-run2/Chao1_diversity_richness.png"
       , gg_chao1
       , height=4, width=5)

ggsave(filename = "/Users/ashleenkhatra/Desktop/MICB_475/Project 2/Re-run2/Chao1_diversity_richness_sf.png"
       , gg_chao1_sf
       , height=4, width=4)

#### Beta diversity analysis ####
#### Bray Curtis ####
bc_dm <- distance(dysautonomia_rare, method="bray")
pcoa_bc <- ordinate(dysautonomia_rare, method="PCoA", distance=bc_dm)
gg_bray <- plot_ordination(dysautonomia_rare, pcoa_bc, color = "FD.severity") + labs(col = "FD Severity Level") + stat_ellipse()

ggsave(filename = "/Users/ashleenkhatra/Desktop/MICB_475/Project 2/Re-run2/Bray_Beta_diversity.png"
       , gg_bray
       , height=4, width=6)

# Betadisper test
dys_dat_wdiv <- data.frame(sample_data(dysautonomia_rare), estimate_richness(dysautonomia_rare))
bc_dm <- distance(dysautonomia_rare, method = "bray")
betadisp_bc <- betadisper(bc_dm, group = dys_dat_wdiv$FD.severity, type = c("centroid"), bias.adjust = FALSE)
permutest(betadisp_bc)
pcoa_bc <- ordinate(dysautonomia_rare, method = "PCoA", distance = bc_dm)     
# p-value is 0.506 (>0.05) so the variance is evenly distributed. The requirements of PERMANOVA are met.

# PERMANOVA Test
dm_bray <- vegdist(t(otu_table(dysautonomia_rare)), method="bray")
adonis2(dm_bray ~ FD.severity, data=samp_dat_wdiv)
# p-value = 0.001

# Pairwise compsrison between control and FD severity groups using PERMANOVA
# Control vs. mild
dys_no_severe_no_mod <- subset_samples(dysautonomia_rare, FD.severity != "severe", FD.severity != "moderate")
### Getting the sample_data info
variables = sample_data(dys_no_severe_no_mod)
variables = data.frame(variables)
### Perform ordination of PCoA method.
bc_dm <- distance(dys_no_severe_no_mod, method="bray")
ord_clr <- phyloseq::ordinate(dys_no_severe_no_mod, "PCoA", distance = bc_dm)
### Plotting PCoA
phyloseq::plot_ordination(dys_no_severe_no_mod, ord_clr, type="FD.severity", color="FD.severity") + 
  geom_point(size = 2) +
  stat_ellipse(aes(group = FD.severity), linetype = 2)
### Generating distance matrix and statistics
clr_dist_matrix <- phyloseq::distance(dys_no_severe_no_mod, method = "bray")
adonis2(clr_dist_matrix ~ Test.FD.severity, data=variables,permutations = 10000)
# p-value is 9.999e-05

# Control vs moderate
dys_no_mild_no_severe <- subset_samples(dysautonomia_rare, FD.severity != "mild", FD.severity != "severe")
### Getting the sample_data info
variables = sample_data(dys_no_mild_no_severe)
variables = data.frame(variables)
### Preform ordination of PCoA method.
bc_dm <- distance(dys_no_mild_no_severe, method="bray")
ord_clr <- phyloseq::ordinate(dys_no_mild_no_severe, "PCoA", distance = bc_dm)
### Plotting PCoA
phyloseq::plot_ordination(dys_no_mild_no_severe, ord_clr, type="FD.severity", color="FD.severity") + 
  geom_point(size = 2) +
  stat_ellipse(aes(group = FD.severity), linetype = 2)
### Generating distance matrix and statistics
clr_dist_matrix <- phyloseq::distance(dys_no_mild_no_severe, method = "bray")
adonis2(clr_dist_matrix ~ Test.FD.severity, data=variables,permutations = 10000)
# p-value is 9.999e-05

# Control vs. severe
dys_no_mild_no_mod <- subset_samples(dysautonomia_rare, FD.severity != "mild", FD.severity != "moderate")
### Getting the sample_data info
variables = sample_data(dys_no_mild_no_mod)
variables = data.frame(variables)
### Perform ordination of PCoA method.
bc_dm <- distance(dys_no_mild_no_mod, method="bray")
ord_clr <- phyloseq::ordinate(dys_no_mild_no_mod, "PCoA", distance = bc_dm)
### Plotting PCoA
phyloseq::plot_ordination(dys_no_mild_no_mod, ord_clr, type="FD.severity", color="FD.severity") + 
  geom_point(size = 2) +
  stat_ellipse(aes(group = FD.severity), linetype = 2)
### Generating distance matrix and statistics
clr_dist_matrix <- phyloseq::distance(dys_no_mild_no_mod, method = "bray")
adonis2(clr_dist_matrix ~ Test.FD.severity, data=variables,permutations = 10000)
# p-value is 9.999e-05


#### Weighted Unifrac ####
bc_dm <- distance(dysautonomia_rare, method="wunifrac")
pcoa_bc <- ordinate(dysautonomia_rare, method="PCoA", distance=bc_dm)
gg_wunifrac <- plot_ordination(dysautonomia_rare, pcoa_bc, color = "FD.severity") + labs(col = "FD Severity Level") + stat_ellipse() + scale_color_manual(values = c("#1A1A1A","#00b4d8","#0077b6","#03045e"))

ggsave(filename = "/Users/ashleenkhatra/Desktop/MICB_475/Project 2/Re-run2/WUnifrac_Beta_diversity.png"
       , gg_wunifrac
       , height=4, width=6)

# Betadisper test
dys_dat_wdiv <- data.frame(sample_data(dysautonomia_rare), estimate_richness(dysautonomia_rare))
betadisp_bc <- betadisper(bc_dm, group = dys_dat_wdiv$FD.severity, type = c("centroid"), bias.adjust = FALSE)
permutest(betadisp_bc)
pcoa_bc <- ordinate(dysautonomia_rare, method = "PCoA", distance = bc_dm)     
# p-value is 0.506 (>0.05) so the variance is evenly distributed. The requirements of PERMANOVA are met. 

# Weighted Unifrac Curtic diversity PERMANOVA Test
dm_unifrac <- UniFrac(dysautonomia_rare, weighted=TRUE)
adonis2(dm_unifrac ~ FD.severity, data=samp_dat_wdiv)
# p-value = 0.001

# Pairwise compsrison between control and FD severity groups using PERMANOVA
# Control vs mild
dys_no_severe_no_mod <- subset_samples(dysautonomia_rare, FD.severity != "severe", FD.severity != "moderate")
### Getting the sample_data info
variables = sample_data(dys_no_severe_no_mod)
variables = data.frame(variables)
### Preform ordination of PCoA method.
wu_dm <- distance(dys_no_severe_no_mod, method="wunifrac")
ord_clr <- phyloseq::ordinate(dys_no_severe_no_mod, "PCoA", distance = wu_dm)
### Plotting PCoA
phyloseq::plot_ordination(dys_no_severe_no_mod, ord_clr, type="FD.severity", color="FD.severity") + 
  geom_point(size = 2) +
  stat_ellipse(aes(group = FD.severity), linetype = 2)
### Generating distance matrix and statistics
clr_dist_matrix <- phyloseq::distance(dys_no_severe_no_mod, method = "wunifrac")
adonis2(clr_dist_matrix ~ Test.FD.severity, data=variables,permutations = 10000)
# p-value is 0.0042 

# Control vs moderate
dys_no_mild_no_severe <- subset_samples(dysautonomia_rare, FD.severity != "mild", FD.severity != "severe")
### Getting the sample_data info
variables = sample_data(dys_no_mild_no_severe)
variables = data.frame(variables)
### Preform ordination of PCoA method.
wu_dm <- distance(dys_no_mild_no_severe, method="wunifrac")
ord_clr <- phyloseq::ordinate(dys_no_mild_no_severe, "PCoA", distance = wu_dm)
### Plotting PCoA
phyloseq::plot_ordination(dys_no_mild_no_severe, ord_clr, type="FD.severity", color="FD.severity") + 
  geom_point(size = 2) +
  stat_ellipse(aes(group = FD.severity), linetype = 2)
### Generating distance matrix and statistics
clr_dist_matrix <- phyloseq::distance(dys_no_mild_no_severe, method = "wunifrac")
adonis2(clr_dist_matrix ~ Test.FD.severity, data=variables,permutations = 10000)
# p-value is 9.999e-05

# Control vs severe
dys_no_mild_no_mod <- subset_samples(dysautonomia_rare, FD.severity != "mild", FD.severity != "moderate")
### Getting the sample_data info
variables = sample_data(dys_no_mild_no_mod)
variables = data.frame(variables)
### Preform ordination of PCoA method.
wu_dm <- distance(dys_no_mild_no_mod, method="wunifrac")
ord_clr <- phyloseq::ordinate(dys_no_mild_no_mod, "PCoA", distance = wu_dm)
### Plotting PCoA
phyloseq::plot_ordination(dys_no_mild_no_mod, ord_clr, type="FD.severity", color="FD.severity") + 
  geom_point(size = 2) +
  stat_ellipse(aes(group = FD.severity), linetype = 2)
### Generating distance matrix and statistics
clr_dist_matrix <- phyloseq::distance(dys_no_mild_no_mod, method = "wunifrac")
adonis2(clr_dist_matrix ~ Test.FD.severity, data=variables,permutations = 10000)
# p-value is 2e-04 

#### Jaccard and unweighted Unifrac Beta analyses ####
## Cannot use these metrics since they did not meet the normal variance assumption for PERMANOVA.

# Jaccard
bc_dm <- distance(dysautonomia_rare, method = "jaccard", binary = TRUE)
pcoa_bc <- ordinate(dysautonomia_rare, method="PCoA", distance=bc_dm)
plot_ordination(dysautonomia_rare, pcoa_bc, color = "FD.severity") + labs(col = "FD Severity Level") + stat_ellipse()
# Betadisper test
dys_dat_wdiv <- data.frame(sample_data(dysautonomia_rare), estimate_richness(dysautonomia_rare))
betadisp_bc <- betadisper(bc_dm, group = dys_dat_wdiv$FD.severity, type = c("centroid"), bias.adjust = FALSE)
permutest(betadisp_bc)
pcoa_bc <- ordinate(dysautonomia_rare, method = "PCoA", distance = bc_dm)     
# p-value is 0.001 (<0.05) so the variance is not evenly distributed. The requirements of PERMANOVA are NOT met.               

# Unweighted Unifrac
bc_dm <- distance(dysautonomia_rare, method="unifrac")
pcoa_bc <- ordinate(dysautonomia_rare, method="PCoA", distance=bc_dm)
plot_ordination(dysautonomia_rare, pcoa_bc, color = "FD.severity")
gg_unifrac <- plot_ordination(dysautonomia_rare, pcoa_bc, color = "FD.severity") +
  labs(col = "FD Severity Level") + stat_ellipse()
# Betadisper test
dys_dat_wdiv <- data.frame(sample_data(dysautonomia_rare), estimate_richness(dysautonomia_rare))
betadisp_bc <- betadisper(bc_dm, group = dys_dat_wdiv$FD.severity, type = c("centroid"), bias.adjust = FALSE)
permutest(betadisp_bc)
pcoa_bc <- ordinate(dysautonomia_rare, method = "PCoA", distance = bc_dm)     
# p-value is 0.001 (<0.05) so the variance is not evenly distributed. The requirements of PERMANOVA are NOT met.               

