#!/usr/bin/env Rscript

#### Loading packages #### 
library(grid)
library(ggvenn)
library(vegan)
library(ape)
library(phyloseq)
library(microbiome)
library(tidyverse)
library(ggVennDiagram)
library(dada2)

#### Loading data #### 
metafp <- "/Users/ashleenkhatra/Desktop/MICB_475/Project 2/Re-run2/re_metadata.tsv"
meta <- read_delim(metafp, delim="\t")

otufp <- "/Users/ashleenkhatra/Desktop/MICB_475/Project 2/Re-run2/feature-table.txt"
otu <- read_delim(file = otufp, delim="\t", skip=1)

taxfp <- "/Users/ashleenkhatra/Desktop/MICB_475/Project 2/Re-run2/taxonomy.tsv"
tax <- read_delim(taxfp, delim="\t")

phylotreefp <- "/Users/ashleenkhatra/Desktop/MICB_475/Project 2/Re-run2/tree.nwk"
phylotree <- read.tree(phylotreefp)

#### Generate table of disease severity#### 
meta_filter <- select(meta, FD.severity)

#### Format data for phyloseq object #### 
samp_df <- as.data.frame(meta_filter) 
rownames(samp_df)<- meta$`sample-id`
SAMP <- sample_data(samp_df)

otu_mat <- as.matrix(otu[,-1]) 
rownames(otu_mat) <- otu$`#OTU ID`
OTU <- otu_table(otu_mat, taxa_are_rows = TRUE) 

tax_mat <- tax %>% 
  select(-Confidence) %>%
  separate(col=Taxon, sep="; ", into = c("Domain","Phylum","Class","Order","Family","Genus","Species")) %>%
  as.matrix()

rownames(tax_mat) <- tax$`Feature ID`
TAX <- tax_table(tax_mat)

#### Create phyloseq object ####
# Merge all into a phyloseq object
dysautonomia <- phyloseq(OTU, SAMP, TAX, phylotree)

#### Filtering the data ####
# Removing chloroplasts, mitochondria, non-bacterial samples
dysautonomia_filt <- subset_taxa(dysautonomia,  Domain == "d__Bacteria" & Class!="c__Chloroplast" & Family !="f__Mitochondria")
# Removing the ASVs that have less than 5 counts total (low abundance ASVs)
dysautonomia_filt_nolow <- filter_taxa(dysautonomia_filt, function(x) sum(x)>5, prune = TRUE)
# Removing low quality samples with less than 100 reads
dysautonomia_filt_nolow_samps <- prune_samples(sample_sums(dysautonomia_filt_nolow)>100, dysautonomia_filt_nolow)
# Remove samples where FD.severity is na
dysautonomia_final <- subset_samples(dysautonomia_filt_nolow_samps, !is.na("FD.severity"))

#### Rarefy samples ####
rarecurve(t(as.data.frame(otu_table(dysautonomia_final))), cex=0.1)
dysautonomia_rare <- rarefy_even_depth(dysautonomia_final, rngseed = 1, sample.size = 9000)
# 54 out of 214 samples were removed
# 80 OTUs were removed

#### Saving the rarefy samples ####
save(dysautonomia_final, file="/Users/ashleenkhatra/Desktop/MICB_475/Project 2/Re-run2/dysautonomia_final.RData")
save(dysautonomia_rare, file="/Users/ashleenkhatra/Desktop/MICB_475/Project 2/Re-run2/dysautonomia_rare.RData")

#### Load in RData ####
load("/Users/ashleenkhatra/Desktop/MICB_475/Project 2/Re-run2/dysautonomia_final.RData")
load("/Users/ashleenkhatra/Desktop/MICB_475/Project 2/Re-run2/dysautonomia_rare.RData")

#### Convert counts to relative abundance #### 
phyloseq_transformed <- transform_sample_counts(dysautonomia_final, function(x) x/sum(x))

#### Filter phyloseq object to different groups #### 
phylo_control <- subset_samples(phyloseq_transformed, FD.severity == "control")
phylo_mild <- subset_samples(phyloseq_transformed, FD.severity == "mild")
phylo_moderate <- subset_samples(phyloseq_transformed, FD.severity == "moderate")
phylo_severe <- subset_samples(phyloseq_transformed, FD.severity == "severe")

# Run core microbiome based on detection = 0.001 and prevalence of 0.75
coreasv_control <- core_members(phylo_control, detection = 0.001, prevalence = 0.75)

coreasv_mild <- core_members(phylo_mild, detection = 0.001, prevalence = 0.75)

coreasv_moderate <- core_members(phylo_moderate, detection = 0.001, prevalence = 0.75)

coreasv_severe <- core_members(phylo_severe, detection = 0.001, prevalence = 0.75)

#### Merging taxa information  #### 
taxa_control <- assignTaxonomy()

#### Plot a taxabarplot for each list of core microbes  #### 
prune_taxa(coreasv_control, phylo_control)%>% 
  plot_bar(, fill = "Genus") + facet_wrap(.~FD.severity, scales = "free")

prune_taxa(coreasv_mild, phylo_mild)%>%
  plot_bar(, fill = "Genus") + facet_wrap(.~FD.severity, scales = "free")

prune_taxa(coreasv_moderate, phylo_moderate)%>%
  plot_bar(, fill = "Genus") + facet_wrap(.~FD.severity, scales = "free")

prune_taxa(coreasv_severe, phylo_severe)%>%
  plot_bar(, fill = "Genus") + facet_wrap(.~FD.severity, scales = "free")

#### Creating a 4-way VennDiagram  #### 
y <- list("Control" = coreasv_control, "Mild" = coreasv_mild, "Moderate" = coreasv_moderate, "Severe" = coreasv_severe)

ggVennDiagram(y, category.names = c("Control", "Mild", "Moderate", "Severe"), stroke_size = 0.5, 
              set_name_size = 4, set_size = 4.5, label_size = 4)  +
  scale_x_continuous(expand = expansion(mult = .3)) +
  scale_color_brewer(palette = ("Set1")) +
  scale_fill_distiller(palette = "Set3", direction = 1)

gg_venn <- ggvenn(y, fill_color = c("#caf0f8", "#00b4d8", "#0077b6", "#03045e"),
       stroke_size = 0.75, set_name_size = 4)

ggsave(filename = "/Users/ashleenkhatra/Desktop/MICB_475/Project 2/Re-run2/core_microbiome_b.png"
       , gg_venn
       , height=4, width=6)


